import styled from 'styled-components';
import Button from '@material-ui/core/Button';

import { colors, fontsStack, fontWeights } from 'themes';

const getStylesBasedOnType = ({ type }) => {
  const bgColors = {
    default: colors['gray-lightest'],
    info: colors['blue-solid'],
    danger: colors['red-solid'],
    success: colors['green-solid'],
  };

  const bgHoverColors = {
    default: colors['gray-hover'],
    info: colors['blue-hover'],
    danger: colors['red-hover'],
    success: colors['green-hover'],
  };

  const color = bgColors[type] || bgColors.info;
  const hoverColor = bgHoverColors[type] || bgHoverColors.info;
  const isDefault = type === 'default';

  return `
    background-color: ${color};
    color: ${isDefault ? colors['purple-medium'] : colors['white-medium']};
    border: ${isDefault ? `1px solid ${colors['gray-solid']}` : 'none'};
    &:hover {
      background-color: ${hoverColor};
      color: ${isDefault ? colors['purple-solid'] : colors['white-solid']};
    }
  `;
};

const getStylesBasedOnSize = ({ size }) => {
  switch (size) {
    case 'medium':
      return `
        min-height: 48px;
      `;
    case 'large':
      return `
        min-height: 56px;
      `;
    case 'xLarge':
      return `
        min-height: 96px;
      `;
    default:
      return `
        min-height: 36px;
      `;
  }
};

export const ButtonStyled = styled(Button)`
  && {
    box-shadow: none;
    border-radius: 3px;
    font-family: ${fontsStack.default};
    font-weight: ${fontWeights.semibold};
    font-size: 16px;
    text-transform: capitalize;
    min-height: 56px;
    padding: 6px 12px;
    align: right;
    ${getStylesBasedOnType};
    ${getStylesBasedOnSize};

    &:active {
      box-shadow: none;
    }
  }
`;
